@@ -6,6 +6,18 @@ from pydantic import BaseModel, validator
 from geojson_pydantic import Polygon
 from pydantic.generics import GenericModel
 
+# --- BASIC GEOMETRIES ---
+
+# Polygon is actually exported from geojson_pydantic automatically, so
+# we'll just leave it like that. From your code, you can just do:
+# from sr_models.base import Polygon
+
+class BoundingBox(BaseModel):
+    north: float
+    south: float
+    east:  float
+    west:  float
+
 # --- SUPPORTED VENDORS ---
 
 class VendorNameEnum(str, Enum):
@@ -13,6 +25,7 @@ class VendorNameEnum(str, Enum):
     up42     = 'up42'
     landsat  = 'landsat'
     sentinel = 'sentinel'
+    goes     = 'goes'
 
 
 class Provider(BaseModel):
